@@ -22,7 +22,7 @@
  * @file BeanSerializer.php
  * @brief serialize bean.
  * @author <a href="mailto:kent@guarana.cc">ISHITOYA Kentaro</a>
- * @version $Id: BeanSerializer.php 2 2007-07-11 10:37:48Z ishitoya $
+ * @version $Id: BeanSerializer.php 48 2007-09-20 07:21:07Z ishitoya $
  */
 
 /**
@@ -34,6 +34,6 @@ interface Ficus_BeanSerializer{
      * @param $bean Ficus_Bean target bean
      * @return string serialized data
      */
-    public function serialize($bean);
+    public function serialize($bean, $arguments = null);
 }
 ?>
