@@ -22,7 +22,7 @@
  * @file FFMpeg.php
  * @brief svn add
  * @author <a href="kent@guarana.cc">ISHITOYA Kentaro</a>
- * @version $Id: FFMpeg.php 19 2007-07-25 18:20:09Z ishitoya $
+ * @version $Id: FFMpeg.php 33 2007-08-19 18:00:31Z ishitoya $
  *
  * executes ffmpeg abstract class
  */
@@ -42,13 +42,6 @@ implements Ficus_FFMpegConstants
      */
     protected $filename = null;
 
-    /**
-     * constructor
-     */
-    public function __construct(){
-        $this->setCommand(self::FFMPEG);
-    }
-    
     /**
      * create command
      * @return string ./ffmpeg -f build.xml
@@ -57,7 +50,7 @@ implements Ficus_FFMpegConstants
         if($this->isEmptyFilename()){
             throw new Ficus_NotReadyException("filename is not specified");
         }
-        $command = $this->command();
+        $command = self::FFMPEG;
         $command = $this->addOption($command, self::INPUT, '"' . $this->filename() . '"');
         return $command;
     }
