@@ -22,7 +22,7 @@
  * @file PDODatabase.php
  * @brief
  * @author <a href="mailto:kent@guarana.cc">ISHITOYA Kentaro</a>
- * @version $Id: PDODatabase.php 12 2007-07-15 14:41:51Z ishitoya $
+ * @version $Id: PDODatabase.php 26 2007-08-01 13:56:06Z ishitoya $
  * 
  *
  */
@@ -45,6 +45,14 @@ class Ficus_PDODatabase extends Ficus_Database
      * @var $errorInfo string errorcode
      */
     protected $errorInfo = null;
+
+    /**
+     * constructor
+     * @param $database PDOObject
+     */
+    public function __construct($database = null){
+        $this->database = $database;
+    }
     
     /**
      * connect to server
