@@ -22,7 +22,7 @@
  * @file S2DaoS2DaoArrayEntityDeserializer.php
  * @brief deserialize Array to Bean.
  * @author <a href="mailto:kent@guarana.cc">ISHITOYA Kentaro</a>
- * @version $Id: S2DaoArrayEntityDeserializer.php 17 2007-07-19 13:33:15Z ishitoya $
+ * @version $Id: S2DaoArrayEntityDeserializer.php 48 2007-09-20 07:21:07Z ishitoya $
  */
 
 require_once "ficus/db/s2dao/models/S2DaoEntity.php";
@@ -60,11 +60,11 @@ implements Ficus_BeanDeserializer, Ficus_S2DaoModelConstants{
         if($data instanceof stdClass){
             $data = (array)$data;
         }
-
+        
         $properties = $reader->properties();
-        $class = get_class($entity);
+        $class = $entity->getEntityName();
         foreach($properties as $property){
-            $key = $class . "_" . $property;
+            $key = $class . "__" . $property;
             if(is_null($parent) == false){
                 $key = $parent . "__" . $key;
             }
@@ -82,7 +82,12 @@ implements Ficus_BeanDeserializer, Ficus_S2DaoModelConstants{
                 }
             }else if($reader->type($property) == self::TYPE_FOREIGN){
                 $prop = $entity->{$getter}();
-                $value = $this->parseArray($prop, $data, $key);
+                if($parent != null){
+                    $t = $parent . "__" . $class;
+                }else{
+                    $t = $class;
+                }
+                $value = $this->parseArray($prop, $data, $t);
                 $entity->{$setter}($value);
             }else if($reader->type($property) == self::TYPE_LIST){
                 if($this->isEmpty($data, $key) == false){
@@ -106,7 +111,8 @@ implements Ficus_BeanDeserializer, Ficus_S2DaoModelConstants{
         if(isset($data[$key]) == false){
             return true;
         }else if($data[$key] === null ||
-                 $data[$key] === ""){
+                 $data[$key] === "" ||
+                 $data[$key] === "null"){
             return true;
         }
         return false;
