@@ -22,7 +22,7 @@
  * @file Runtime.php
  * @brief execute command line commands
  * @author <a href="kent@guarana.cc">ISHITOYA Kentaro</a>
- * @version $Id: Runtime.php 19 2007-07-25 18:20:09Z ishitoya $
+ * @version $Id: Runtime.php 54 2007-09-27 19:37:15Z ishitoya $
  * 
  * utility to execute command line command
  */
@@ -36,6 +36,11 @@ require_once("ficus/lang/PlatformInformation.php");
 class Ficus_Runtime
 {
     const ERROR = "error";
+    const POPEN = "popen";
+    const PROCOPEN = "proc_open";
+    const EXEC = "exec";
+    const SYSTEM = "system";
+    const PASSTHRU = "passthru";
 
     /**
      * command search path
@@ -55,9 +60,10 @@ class Ficus_Runtime
      * @return array of env
      */
     private static function createEnv(){
+        $env = $_ENV;
         if(empty(self::$paths) == false){
-            $path = implode(PATH_SEPARATOR, self::$paths);
-            return array('PATH' => $path);
+            $path = implode(PATH_SEPARATOR, self::$paths);            
+            return array_merge($env, array('PATH' => $path));
         }
         return null;
     }
@@ -69,7 +75,8 @@ class Ficus_Runtime
      * @return array of command output.
      * @throw Ficus_TypeMismatchException
      */
-    public static function exec($command, $parameters = null){
+    public static function exec($command,
+                                $parameters = null, $executer = self::PROCOPEN){
         Ficus_Assert::isPrimitiveTypeAllowNull($parameters, "array");
         if(is_null($parameters) == false){
             foreach($parameters as $key => $p){
@@ -78,26 +85,80 @@ class Ficus_Runtime
             $param = implode(' ', $parameters);
             $command .= ' ' . $param;
         }
+
+        switch($executer){
+        case (self::PROCOPEN):
+            return self::execProcOpen($command);
+        case (self::EXEC):
+            return self::execExec($command);
+        case (self::PASSTHRU):
+            return self::execPassthru($command);
+        case (self::POPEN):
+            return self::execPopen($command);
+        }
+        return null;
+    }
+
+    /**
+     * execute with exec
+     */
+    protected static function execExec($command){
+        exec($command, $output, $result);
+        return $output;
+    }
+
+    /**
+     * execute with popen
+     */
+    protected static function execPopen($command){
+        $command = $command . " 2>&1";
+        $handle = popen($command, 'r');
+        $output = fread($handle, 20960);
+        pclose($handle);
+        return $output;
+    }
+
+    /**
+     * execute with passthru
+     */
+    protected static function execPassthru($command){
+        ob_start();
+        passthru($command, $result);
+        $output = ob_get_contents();
+        ob_end_clean();
+        return $output;
+    }
+
+    /**
+     * execute with proc open
+     */
+    protected static function execProcOpen($command){
+        $file = tempnam(null, "FicusLangRuntime");
         $specs = array(
             0 => array('pipe', 'r'),
             1 => array('pipe', 'w'),
-            2 => array('pipe', 'w'));
+            2 => array('file', $file, 'a'));
         $env = self::createEnv();
+        $opt = array("bypass_shell" => true);
 
-        $process = proc_open($command, $specs, $pipes, null, $env);
+        $process = proc_open($command, $specs, $pipes, null, $env, $opt);
 
         if(is_resource($process) == false){
             throw new Ficus_NotReadyException("Process is not started. command is $command.");
         }        
 
+        fclose($pipes[0]);
         $output = stream_get_contents($pipes[1]);
         fclose($pipes[1]);
-        $error = stream_get_contents($pipes[2]);
-        fclose($pipes[2]);
+        
+        $error = file_get_contents($file);
+        if(is_writable($file)){
+            unlink($file);
+        }
         $output = explode("\n", $output);
         $output[self::ERROR] = $error;
+        proc_terminate($process);
         proc_close($process);
-
         return $output;
     }
 
@@ -123,7 +184,7 @@ class Ficus_Runtime
             1 => array('pipe', 'w'),
             2 => array('pipe', 'w'));
         $env = self::createEnv();
-        $process = proc_open($command, $specs, $pipes, null, $env);
+        $process = proc_open($command, $specs, $pipes, null, $env, array());
 
         if(is_resource($process) == false){
             throw new Ficus_NotReadyException("Process is not started. command is $command.");
