@@ -22,7 +22,7 @@
  * @file PageComponentFactory.php
  * @brief Page component factory
  * @author <a href="mailto:kent@guarana.cc">ISHITOYA Kentaro</a>
- * @version $Id: PageComponentFactory.php 17 2007-07-19 13:33:15Z ishitoya $
+ * @version $Id: PageComponentFactory.php 37 2007-08-28 01:17:50Z ishitoya $
  * 
  * Page component factory
  */
@@ -221,7 +221,29 @@ implements Ficus_PageConstants{
      */
     public static function getAuthorization($page, $prefix = ""){
         Ficus_Assert::isInstanceOf($page, "Ficus_Page");
-        $name = $prefix . $page->getPagename() . "PageAuthorization";
+        $name = $prefix . ucfirst($page->getPagename()) . "PageAuthorization";
+        return self::getComponent($name);
+    }
+    
+    /**
+     * get AuthenticationManager
+     */
+    public static function getAuthenticationManager(){
+        $manager =
+            Ficus_Registry::search(self::REGISTRY_AUTHENTICATION_MANAGER);
+        if($manager == false){
+            return null;
+        }
+        $name = ucfirst($manager) . "PageAuthenticationManager";
+        return self::getComponent($name);
+    }
+
+    /**
+     * get Listener
+     */
+    public static function getListener($name){
+        $name = strtolower($name[0]) . substr($name, 1);
+        $name .= "Listener";
         return self::getComponent($name);
     }
 }
