@@ -22,7 +22,7 @@
  * @file PageConstants.php
  * @brief Page component factory
  * @author <a href="mailto:kent@guarana.cc">ISHITOYA Kentaro</a>
- * @version $Id: PageConstants.php 7 2007-07-14 10:55:18Z ishitoya $
+ * @version $Id: PageConstants.php 35 2007-08-24 11:15:33Z ishitoya $
  * 
  * Page component factory
  */
@@ -122,6 +122,10 @@ interface Ficus_PageConstants {
      */
     const REGISTRY_DEFAULT = "pages.default";
 
+    /**
+     * visit
+     */
+    const REGISTRY_VISIT = "visit";
     
     /**
      * default smarty plugins
@@ -257,5 +261,10 @@ interface Ficus_PageConstants {
      * template name
      */
     const TEMPLATE_NAME = "pages";
+
+    /**
+     * registry authorization manager
+     */
+    const REGISTRY_AUTHENTICATION_MANAGER = "pages.authentication.manager";
 }
 ?>
