@@ -22,7 +22,7 @@
  * @file PageLoader.php
  * @brief controll page
  * @author <a href="mailto:kent@guarana.cc">ISHITOYA Kentaro</a>
- * @version $Id: PageLoader.php 7 2007-07-14 10:55:18Z ishitoya $
+ * @version $Id: PageLoader.php 35 2007-08-24 11:15:33Z ishitoya $
  */
 
 require_once("ficus/pages/ConcretePage.php");
@@ -129,7 +129,7 @@ class Ficus_PageLoader implements Ficus_PageConstants{
             throw new Ficus_IllegalArgumentException("template name is empty");
         }
         
-        $name = str_replace("_", ".", $name);
+        $name = ucfirst(str_replace("_", ".", $name));
         foreach($this->prefixes as $prefix){
             $classname = $this->getClassName($prefix, $name);
             try{
