@@ -22,7 +22,7 @@
  * @file PageRequest.php
  * @brief request wrapper
  * @author <a href="mailto:kent@guarana.cc">ISHITOYA Kentaro</a>
- * @version $Id: PageRequest.php 15 2007-07-18 15:02:48Z ishitoya $
+ * @version $Id: PageRequest.php 54 2007-09-27 19:37:15Z ishitoya $
  */
 
 /**
@@ -50,13 +50,15 @@ class Ficus_PageRequest extends Ficus_Bean{
      */
     protected function createArguments($args){
         $request = array_merge($_POST, $_GET);
-        array_shift($args);
-        array_shift($args);
-        array_shift($args);
         $result = array();
+        if(empty($args)){
+            $args = array();
+        }
         foreach($args as $arg){
             if(is_array($arg)){
                 $result[key($arg)] = $arg[key($arg)];
+            }else{
+                $result[] = $arg;
             }
         }
         foreach($request as $key => $arg){
@@ -65,6 +67,19 @@ class Ficus_PageRequest extends Ficus_Bean{
         return $result;
     }
 
+    /**
+     * get raw data
+     * @param $name name of request
+     * @return misc
+     */
+    public function get($name){
+        if(isset($this->requests[$name])){
+            return $this->requests[$name];
+        }else{
+            return parent::get($name);
+        }
+    }
+
     /**
      * extract 
      * @param $args array of arguments
@@ -78,21 +93,22 @@ class Ficus_PageRequest extends Ficus_Bean{
             return null;
         }
         
-        $argument = $args[$name];
-        if(is_string($argument)){
-            $argument = trim($argument);
-            $argument = Ficus_Types::cast($argument, $type);
-            Ficus_Assert::isPrimitiveType($argument, $type);
-        }else if(is_array($argument)){
-            foreach($argument as $key => $value){
+        $arguments = $args[$name];
+        if(is_string($arguments)){
+            $arguments = stripslashes(trim($arguments));
+            $arguments = Ficus_Types::cast($arguments, $type);
+            Ficus_Assert::isPrimitiveType($arguments, $type);
+        }else if(is_array($arguments)){
+            foreach($arguments as $key => $value){
                 $value = trim($value);
-                $value = Ficus_Types::cast($value, $type);
-
-                Ficus_Assert::isPrimitiveType($value, $type);
-                $argument[$key] = $value;
+                if($type != "array" && count($type) != 1){
+                    $value = Ficus_Types::cast($value, $type);
+                    Ficus_Assert::isPrimitiveType($value, $type);
+                }
+                $arguments[$key] = $value;
             }
         }
-        return $argument;
+        return $arguments;
     }
 
     /**
@@ -118,5 +134,18 @@ class Ficus_PageRequest extends Ficus_Bean{
         }
         return parent::__call($name, $arguments);
     }
+
+    /**
+     * search
+     */
+    public function search($pattern){
+        $result = array();
+        foreach($this->requests as $key => $value){
+            if(preg_match($pattern, $key)){
+                $result[$key] = $value;
+            }
+        }
+        return $result;
+    }
 }
 ?>
