@@ -22,7 +22,7 @@
  * @file AbstractScaffoldForeperson.php
  * @brief index page of administrator site
  * @author <a href="mailto:kent@guarana.cc">ISHITOYA Kentaro</a>
- * @version $Id: AbstractScaffoldForeperson.php 19 2007-07-25 18:20:09Z ishitoya $
+ * @version $Id: AbstractScaffoldForeperson.php 48 2007-09-20 07:21:07Z ishitoya $
  */
 
 require_once("ficus/config/Registry.php");
@@ -41,7 +41,7 @@ implements Ficus_ScaffoldForeperson, Ficus_ScaffoldConstants{
     public function __construct($mediator, $action){
         $this->mediator = $mediator;
         $this->action = $action;
-        $this->prepare($action);
+        $this->prepare($this->action);
     }
 
     /**
