@@ -22,7 +22,7 @@
  * @file DeleteScaffoldForeperson.php
  * @brief table manager page
  * @author <a href="mailto:kent@guarana.cc">ISHITOYA Kentaro</a>
- * @version $Id: DeleteScaffoldForeperson.php 14 2007-07-18 14:55:12Z ishitoya $
+ * @version $Id: DeleteScaffoldForeperson.php 48 2007-09-20 07:21:07Z ishitoya $
  */
 
 require_once("ficus/pages/AbstractPage.php");
@@ -38,30 +38,25 @@ class Ficus_DeleteScaffoldForeperson extends Ficus_AbstractScaffoldForeperson{
     public function doDefault(){
         $ids = $this->mediator->request()->extractAsInt(self::KEY_IDS);
         $entities = $this->mediator->daoManager()->getEntities($ids);
-        $container = $this->mediator->getContainer($entities);
-
-        $organizer =
-            $this->mediator->organizerFactory()->createListOrganizer();
-        $organizer->setItemTemplate("item");
-        $organizer->setRowTemplate("row");
-        $organizer->setHeaderTemplate("header");
-        $organizer->setEntityTemplate("table");
-        $container->addOrganizers($organizer);
+        $scaffold =
+            $this->mediator->getScaffold($entities, self::ACTION_VIEW);
 
         $this->mediator->smarty()->assign(self::KEY_IDS, $ids);
-        $this->mediator->formBean()->setDo(self::DO_SUBMIT);
-        return $container->build();
+        $this->mediator->scaffold()->setDo(self::DO_SUBMIT);
+        return $scaffold->serialize("ListScaffold");
     }
     
     /**
      * delete submit
      */
     public function doSubmit(){
-        $ids = $this->mediator->request()->extractAsString(self::KEY_IDS);
+        $ids = $this->mediator->request()->extractAsInt(self::KEY_IDS);
 
         $dao = $this->mediator->daoManager()->dao();
+        $pdo = $this->mediator->daoManager()->pdo();
         $entity = $dao->entity();
         foreach($ids as $id){
+            $pdo->query("DELETE FROM histories WHERE person_id = $id");
             $entity->setId($id);
             $dao->delete($entity);
         }
