@@ -22,7 +22,7 @@
  * @file ScaffoldConstants.php
  * @brief scaffold interface
  * @author <a href="mailto:kent@guarana.cc">ISHITOYA Kentaro</a>
- * @version $Id: ScaffoldConstants.php 15 2007-07-18 15:02:48Z ishitoya $
+ * @version $Id: ScaffoldConstants.php 51 2007-09-24 13:39:45Z ishitoya $
  */
 
 require_once("ficus/config/Registry.php");
@@ -45,6 +45,7 @@ interface Ficus_ScaffoldConstants{
     const REGISTRY_VALIDATORS = "validators";
     const REGISTRY_CONSTRAINT = "constraint";
     const REGISTRY_PARENT = "parent";
+    const REGISTRY_ASSISTS = "assists";
 
     const METHOD_PREFIX = "do";
 
@@ -77,6 +78,7 @@ interface Ficus_ScaffoldConstants{
     const KEY_HELPER = "scaffold_helper";
     const KEY_ID     = "scaffold_id";
     const KEY_IDS    = "scaffold_ids";
+    const KEY_OFFSET = "scaffold_offset";
 
     const METHOD_POST = "post";
     const METHOD_GET  = "get";
