@@ -22,7 +22,7 @@
  * @file AbstractScaffoldBuilder.php
  * @brief AbstractScaffoldBuilder.
  * @author <a href="mailto:kent@guarana.cc">ISHITOYA Kentaro</a>
- * @version $Id: ConcreteScaffoldBuilder.php 14 2007-07-18 14:55:12Z ishitoya $
+ * @version $Id: ConcreteScaffoldBuilder.php 48 2007-09-20 07:21:07Z ishitoya $
  *
  */
 
@@ -53,13 +53,13 @@ implements Ficus_ScaffoldBuilder, Ficus_ScaffoldConstants{
      */
     public function build($entity){
         if($entity instanceof S2Dao_ArrayList){
-            $list = new Ficus_ScaffoldPartsContainerList();
             foreach($entity as $target){
-                $list->addContainers($this->createContainer($target));
+                $this->mediator->scaffold()->add(
+                                        $this->createScaffold($target));
             }
-            return $list;
         }else{
-            return $this->createContainer($entity);
+            $scaffold = $this->createScaffold($entity);
+            $this->mediator->scaffold()->setEntities($scaffold->entities());
         }
     }
 
@@ -68,12 +68,16 @@ implements Ficus_ScaffoldBuilder, Ficus_ScaffoldConstants{
      * @param $parts array of parts
      * @return Ficus_ConcreateScaffoldPartsContainer
      */
-    protected function createContainer($entity){
+    protected function createScaffold($entity){
         Ficus_Assert::isInstanceOf($entity, "Ficus_S2DaoEntity");
-        $parts = $this->buildParts($entity);
-        $container = new Ficus_ConcreteScaffoldPartsContainer($entity);
-        $container->setParts($parts);
-        return $container;
+        $scaffold = new Ficus_Scaffold();
+        $scaffold->setConfig($this->mediator->scaffold()->config());
+
+        $entities = $this->buildEntities($entity);
+        foreach($entities as $entity){
+            $scaffold->add($entity);
+        }
+        return $scaffold;
     }
     
     /**
@@ -81,22 +85,20 @@ implements Ficus_ScaffoldBuilder, Ficus_ScaffoldConstants{
      * @param $entity Ficus_S2DaoEntity target entity
      * @return array of parts
      */
-    protected function buildParts($entity){
+    protected function buildEntities($entity, $parent = null){
+        $entity->fetch();
         $reader = new Ficus_S2DaoEntityAnnotationReader($entity);
 
-        $settings = $this->mediator->table($entity->getEntityName());
-        if($settings->isEmptyParentPart("parent") == false){
-            $settings = $this->mediator->table($settings->parentPart());
-        }
-        $settings = $settings->properties();
+        $config = $this->mediator->table($entity->getEntityName());
+
+        $settings = $config->properties();
         $reader->sort($settings);
            
         $parts = array();
         $properties = $reader->properties();
         foreach($properties as $property){
             $value = $entity->get($property);
-            $setting = $settings[$property];
-            $part = $this->buildPart($reader, $property, $value, $setting);
+            $part = $this->buildEntity($reader, $property, $value, $parent);
             $parts[$property] = $part;
         }
         return $parts;
@@ -110,33 +112,27 @@ implements Ficus_ScaffoldBuilder, Ficus_ScaffoldConstants{
      * @param $value mixed value
      * @return Ficus_ScaffoldPart part
      */
-    protected function buildPart($reader, $property, $value, $setting){
+    protected function buildEntity($reader, $property, $value, $parent = null){
         $type = $reader->type($property);
         $label = $reader->label($property);
         $remark = $reader->remark($property);
         $datatype = $reader->datatype($property);
-        $validators = $setting[self::REGISTRY_VALIDATORS];
-        $constraint = $setting[self::REGISTRY_CONSTRAINT];
-
-        $part = Ficus_ScaffoldPartsFactory::create(
-                                  $property, $type, $datatype);
-        $part->setEntity($reader->getTarget());
-        $part->setName($property);
-        $part->setType($type);
-        $part->setLabel($label);
-        $part->setRemark($remark);
-        $part->setValidators($validators);
-        $part->setConstraint($constraint);
+        $entity = new Ficus_ScaffoldEntity();
+        
+        $entity->setEntity($reader->getTarget());
+        $entity->setName($property);
+        $entity->setType($type);
+        $entity->setLabel($label);
+        $entity->setRemark($remark);
+        $entity->setParent($parent);
 
         if($value instanceof Ficus_S2DaoEntity){
-            $parts = $this->buildParts($value);
-            foreach($parts as $child){
-                $child->setParent($part);
-            }
-            $part->setParts($parts);
+            $entities = $this->buildEntities($value, $entity);
+            $entity->setParts($entities);
         }
-        $part->setValue($value);
-        return $part;
+        $entity->setValue($value);
+        $entity->initialize();
+        return $entity;
     }
 }
 ?>
\ No newline at end of file
