@@ -22,7 +22,7 @@
  * @file Smarty.php
  * @brief Smarty.
  * @author <a href="mailto:kent@guarana.cc">ISHITOYA Kentaro</a>
- * @version $Id: Smarty.php 15 2007-07-18 15:02:48Z ishitoya $
+ * @version $Id: Smarty.php 30 2007-08-09 03:57:28Z ishitoya $
  *
  */
 
@@ -98,7 +98,7 @@ class Ficus_Smarty{
      * set id
      */
     public function setCompileId($id){
-        $this->smarty->compile_id = $id;
+        $this->smarty->compile_id = md5($id);
     }
     
     /**
@@ -129,6 +129,7 @@ class Ficus_Smarty{
 
         $path = $paths[0];
         $this->assign("smarty_AbsolutePath", dirname($path));
+        $this->setCompileId($path);
         return "file:" . $path;
     }
 
@@ -187,5 +188,15 @@ class Ficus_Smarty{
         $this->smarty->clear_assign($name);
     }
 
+    /**
+     * get template vars
+     */
+    public function getAssigned($name = null){
+        if(is_null($name)){
+            return $this->smarty->get_template_vars();
+        }else{
+            return $this->smarty->get_template_vars($name);
+        }
+    }
 }
 ?>
